# Filtering Fact Sheets (GraphQL)
### On this page
  * [Filtering Fact Sheets by Type](https://help.sap.com/docs/leanix/ea/filtering-fact-sheets#filtering-fact-sheets-by-type)
  * [Filtering Fact Sheets by Type and Technical Fit](https://help.sap.com/docs/leanix/ea/filtering-fact-sheets#filtering-fact-sheets-by-type-and-technical-fit)
  * [Filtering Fact Sheets by Type and Lifecycle Phase](https://help.sap.com/docs/leanix/ea/filtering-fact-sheets#filtering-fact-sheets-by-type-and-lifecycle-phase)
  * [Filtering Fact Sheets by Type and Tags](https://help.sap.com/docs/leanix/ea/filtering-fact-sheets#filtering-fact-sheets-by-type-and-tags)
  * [Filtering Fact Sheets by External ID](https://help.sap.com/docs/leanix/ea/filtering-fact-sheets#filtering-fact-sheets-by-external-id)
  * [Filtering Archived Fact Sheets](https://help.sap.com/docs/leanix/ea/filtering-fact-sheets#filtering-archived-fact-sheets)
  * [Filtering Fact Sheets by Fields on Relations](https://help.sap.com/docs/leanix/ea/filtering-fact-sheets#filtering-fact-sheets-by-fields-on-relations)
  * [Filtering Fact Sheets by Subscriptions](https://help.sap.com/docs/leanix/ea/filtering-fact-sheets#filtering-fact-sheets-by-subscriptions)


Example queries for filtering fact sheets through the GraphQL API.
The following examples show how to apply facet filters when using the allFactSheets query to retrieve fact sheets. To learn how filtering in GraphQL works and how to retrieve facet keys, see [Filtering in GraphQL](https://help.sap.com/docs/leanix/ea/filtering-in-graphql?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how filtering in GraphQL works and how to apply filters to your queries.").
